Module data

Module data 

Data container implementations.

Modules

operations
Implementations of various operations on data.
vec
Data container implementations for Vec<U>.

Structs

SerializableDatumType

Enums

DatumType
These are core supported data types stored in an enum, to unify the types that come out of standard operations of heterogeneous output types.