pub struct LeftGroupedJoin {
pub left: RangeTuple,
pub rights: Vec<RangeTuple>,
}Expand description
LeftGroupedJoin contains information about the right ranges
and their degree of overlap with a focal left range. This information
is designed to facilitate downstream statistical sumamries of the
corresponding data in overlapping ranges.
Fields
left: RangeTupleThe left range.
rights: Vec<RangeTuple>A Vec of the right overlapping ranges (unsorted).
Implementations
Sourceimpl LeftGroupedJoin
impl LeftGroupedJoin
Sourcepub fn new<R: GenericRange>(left_range: &R) -> Self
pub fn new<R: GenericRange>(left_range: &R) -> Self
Create a new LeftGroupedJoin.
Sourcepub fn add_right<R: GenericRange>(&mut self, right: &R)
pub fn add_right<R: GenericRange>(&mut self, right: &R)
Add a right (overlapping) range to this LeftGroupedJoin.
Sourcepub fn sort_ranges(&mut self)
pub fn sort_ranges(&mut self)
Sort the right ranges, for faster downstream processing.
Sourcepub fn reduce_ranges(&mut self) -> Vec<RangeReduced>
pub fn reduce_ranges(&mut self) -> Vec<RangeReduced>
“Reduce” the ranges into a minimum set, with all
their indices gathered in a Vec<Option<usize>>.
This returns a Vec<RangeReduced>.
Sourcepub fn has_overlaps(&self) -> bool
pub fn has_overlaps(&self) -> bool
Return whether this left range has any LeftGroupedJoin.
Sourcepub fn num_overlaps(&self) -> usize
pub fn num_overlaps(&self) -> usize
Retrieve the number of right overlaps.
Sourcepub fn left_index(&self) -> Option<usize>
pub fn left_index(&self) -> Option<usize>
Get the left index.
Sourcepub fn right_indices(&self) -> Vec<Option<usize>>
pub fn right_indices(&self) -> Vec<Option<usize>>
Get the right indices.