LazyNucleotideSequences

Struct LazyNucleotideSequences 

pub struct LazyNucleotideSequences { /* private fields */ }
A lazy-loaded set of nucleotide sequences based on indexed FASTA files

Implementations

Source

impl LazyNucleotideSequences

pub fn new( filepath: impl Into<PathBuf>, seqnames: Option<Vec<String>>, ) -> Result<Self, GRangesError>

Create a new LazyNucleotideSequences, which can lazyily retrieve regions and whole sequences from an indexed FASTA file.

Arguments
  • filepath - the path to the bgzipped and indexed FASTA file.
  • seqnames - optional vector of sequences to consider (i.e. used for iterators over sequences).
pub fn is_empty(&self) -> bool

Check of the lazy-loading cache is empty.

pub fn clear(&self)

Clear the lazy-loading cache.

pub fn seqlens(&self) -> IndexMap<String, Position>

Get an IndexMap of the sequence names and their lengths.

pub fn is_loaded(&self, key: &str) -> bool

Return a bool indicating whether the specified key is cached.

Arguments
  • key: a &str key passed to the loader function.